// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `constant` vocabulary
//!
//! This module requires `ns-constant` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**||
//! |**Prefix**|constant|
//! |**Namespace base IRI**|<http://qudt.org/vocab/constant/>|
//! |**Description**||
//! |**Is defined by**|<http://qudt.org/vocab/constant/>|
//!

use crate::namespace;

namespace!(
    "http://qudt.org/vocab/constant/",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `Alpha particle-electron mass ratio`: 
    AlphaParticleElectronMassRatio, "AlphaParticleElectronMassRatio",
    /// `Alpha particle mass`: 
    AlphaParticleMass, "AlphaParticleMass",
    /// `alpha particle mass energy equivalent`: 
    AlphaParticleMassEnergyEquivalent, "AlphaParticleMassEnergyEquivalent",
    /// `Alpha particle mass energy equivalent in Me V`: 
    AlphaParticleMassEnergyEquivalentInMeV, "AlphaParticleMassEnergyEquivalentInMeV",
    /// `alpha particle mass in atomic mass unit`: 
    AlphaParticleMassInAtomicMassUnit, "AlphaParticleMassInAtomicMassUnit",
    /// `alpha particle molar mass`: 
    AlphaParticleMolarMass, "AlphaParticleMolarMass",
    /// `alpha particle-proton mass ratio`: 
    AlphaParticleProtonMassRatio, "AlphaParticleProtonMassRatio",
    /// `Angstrom star`: 
    AngstromStar, "AngstromStar",
    /// `atomic mass constant`: 
    AtomicMassConstant, "AtomicMassConstant",
    /// `atomic mass constant energy equivalent`: 
    AtomicMassConstantEnergyEquivalent, "AtomicMassConstantEnergyEquivalent",
    /// `atomic mass constant energy equivalent in MeV`: 
    AtomicMassConstantEnergyEquivalentInMeV, "AtomicMassConstantEnergyEquivalentInMeV",
    /// `atomic mass unit-electron volt relationship`: 
    AtomicMassUnitElectronVoltRelationship, "AtomicMassUnitElectronVoltRelationship",
    /// `atomic mass unit-hartree relationship`: 
    AtomicMassUnitHartreeRelationship, "AtomicMassUnitHartreeRelationship",
    /// `atomic mass unit-hertz relationship`: 
    AtomicMassUnitHertzRelationship, "AtomicMassUnitHertzRelationship",
    /// `atomic mass unit-inverse meter relationship`: 
    AtomicMassUnitInverseMeterRelationship, "AtomicMassUnitInverseMeterRelationship",
    /// `atomic mass unit-joule relationship`: 
    AtomicMassUnitJouleRelationship, "AtomicMassUnitJouleRelationship",
    /// `atomic mass unit-kelvin relationship`: 
    AtomicMassUnitKelvinRelationship, "AtomicMassUnitKelvinRelationship",
    /// `atomic mass unit-kilogram relationship`: 
    AtomicMassUnitKilogramRelationship, "AtomicMassUnitKilogramRelationship",
    /// `atomic unit of 1st hyperpolarizablity`: 
    AtomicUnitOf1stHyperpolarizablity, "AtomicUnitOf1stHyperpolarizablity",
    /// `atomic unit of 2nd hyperpolarizablity`: 
    AtomicUnitOf2ndHyperpolarizablity, "AtomicUnitOf2ndHyperpolarizablity",
    /// `atomic unit of action`: 
    AtomicUnitOfAction, "AtomicUnitOfAction",
    /// `atomic unit of charge`: 
    AtomicUnitOfCharge, "AtomicUnitOfCharge",
    /// `atomic unit of charge density`: 
    AtomicUnitOfChargeDensity, "AtomicUnitOfChargeDensity",
    /// `atomic unit of current`: 
    AtomicUnitOfCurrent, "AtomicUnitOfCurrent",
    /// `atomic unit of electric dipole mom.`: 
    AtomicUnitOfElectricDipoleMoment, "AtomicUnitOfElectricDipoleMoment",
    /// `atomic unit of electric field`: 
    AtomicUnitOfElectricField, "AtomicUnitOfElectricField",
    /// `atomic unit of electric field gradient`: 
    AtomicUnitOfElectricFieldGradient, "AtomicUnitOfElectricFieldGradient",
    /// `atomic unit of electric polarizablity`: 
    AtomicUnitOfElectricPolarizablity, "AtomicUnitOfElectricPolarizablity",
    /// `atomic unit of electric potential`: 
    AtomicUnitOfElectricPotential, "AtomicUnitOfElectricPotential",
    /// `atomic unit of electric quadrupole moment`: 
    AtomicUnitOfElectricQuadrupoleMoment, "AtomicUnitOfElectricQuadrupoleMoment",
    /// `atomic unit of energy`: 
    AtomicUnitOfEnergy, "AtomicUnitOfEnergy",
    /// `atomic unit of force`: 
    AtomicUnitOfForce, "AtomicUnitOfForce",
    /// `atomic unit of length`: 
    AtomicUnitOfLength, "AtomicUnitOfLength",
    /// `atomic unit of magnetic dipole moment`: 
    AtomicUnitOfMagneticDipoleMoment, "AtomicUnitOfMagneticDipoleMoment",
    /// `atomic unit of magnetic flux density`: 
    AtomicUnitOfMagneticFluxDensity, "AtomicUnitOfMagneticFluxDensity",
    /// `atomic unit of magnetizability`: 
    AtomicUnitOfMagnetizability, "AtomicUnitOfMagnetizability",
    /// `atomic unit of mass`: 
    AtomicUnitOfMass, "AtomicUnitOfMass",
    /// `atomic unit of momentum`: 
    AtomicUnitOfMomentum, "AtomicUnitOfMomentum",
    /// `atomic unit of permittivity`: 
    AtomicUnitOfPermittivity, "AtomicUnitOfPermittivity",
    /// `atomic unit of time`: 
    AtomicUnitOfTime, "AtomicUnitOfTime",
    /// `atomic unit of velocity`: 
    AtomicUnitOfVelocity, "AtomicUnitOfVelocity",
    /// `Avogadro constant`: 
    AvogadroConstant, "AvogadroConstant",
    /// `Bohr Magneton`: 
    BohrMagneton, "BohrMagneton",
    /// `Bohr magneton in eV per T`: 
    BohrMagnetonInEVPerT, "BohrMagnetonInEVPerT",
    /// `Bohr magneton in Hz perT`: 
    BohrMagnetonInHzPerT, "BohrMagnetonInHzPerT",
    /// `Bohr magneton in inverse meters per tesla`: 
    BohrMagnetonInInverseMetersPerTesla, "BohrMagnetonInInverseMetersPerTesla",
    /// `Bohr magneton in K per T`: 
    BohrMagnetonInKPerT, "BohrMagnetonInKPerT",
    /// `Bohr Radius`: 
    BohrRadius, "BohrRadius",
    /// `Boltzmann Constant`: 
    BoltzmannConstant, "BoltzmannConstant",
    /// `Boltzmann constant in eV per K`: 
    BoltzmannConstantInEVPerK, "BoltzmannConstantInEVPerK",
    /// `Boltzmann constant in Hz per K`: 
    BoltzmannConstantInHzPerK, "BoltzmannConstantInHzPerK",
    /// `Boltzmann constant in inverse meters per kelvin`: 
    BoltzmannConstantInInverseMetersPerKelvin, "BoltzmannConstantInInverseMetersPerKelvin",
    /// `characteristic impedance of vacuum`: 
    CharacteristicImpedanceOfVacuum, "CharacteristicImpedanceOfVacuum",
    /// `classical electron radius`: 
    ClassicalElectronRadius, "ClassicalElectronRadius",
    /// `Compton Wavelength`: 
    ComptonWavelength, "ComptonWavelength",
    /// `Compton wavelength over 2 pi`: 
    ComptonWavelengthOver2Pi, "ComptonWavelengthOver2Pi",
    /// `conductance quantum`: 
    ConductanceQuantum, "ConductanceQuantum",
    /// `conventional value of Josephson constant`: 
    ConventionalValueOfJosephsonConstant, "ConventionalValueOfJosephsonConstant",
    /// `conventional value of von Klitzing constant`: 
    ConventionalValueOfVonKlitzingConstant, "ConventionalValueOfVonKlitzingConstant",
    /// `Cu x unit`: 
    CuXUnit, "CuXUnit",
    /// `deuteron-electron magnetic moment ratio`: 
    DeuteronElectronMagneticMomentRatio, "DeuteronElectronMagneticMomentRatio",
    /// `deuteron-electron mass ratio`: 
    DeuteronElectronMassRatio, "DeuteronElectronMassRatio",
    /// `deuteron g factor`: 
    DeuteronGFactor, "DeuteronGFactor",
    /// `deuteron magnetic moment`: 
    DeuteronMagneticMoment, "DeuteronMagneticMoment",
    /// `deuteron magnetic moment to Bohr magneton ratio`: 
    DeuteronMagneticMomentToBohrMagnetonRatio, "DeuteronMagneticMomentToBohrMagnetonRatio",
    /// `deuteron magnetic moment to nuclear magneton ratio`: 
    DeuteronMagneticMomentToNuclearMagnetonRatio, "DeuteronMagneticMomentToNuclearMagnetonRatio",
    /// `deuteron mass`: 
    DeuteronMass, "DeuteronMass",
    /// `deuteron mass energy equivalent`: 
    DeuteronMassEnergyEquivalent, "DeuteronMassEnergyEquivalent",
    /// `deuteron mass energy equivalent in MeV`: 
    DeuteronMassEnergyEquivalentInMeV, "DeuteronMassEnergyEquivalentInMeV",
    /// `deuteron mass in atomic mass unit`: 
    DeuteronMassInAtomicMassUnit, "DeuteronMassInAtomicMassUnit",
    /// `deuteron molar mass`: 
    DeuteronMolarMass, "DeuteronMolarMass",
    /// `deuteron-neutron magnetic moment ratio`: 
    DeuteronNeutronMagneticMomentRatio, "DeuteronNeutronMagneticMomentRatio",
    /// `deuteron-proton magnetic moment ratio`: 
    DeuteronProtonMagneticMomentRatio, "DeuteronProtonMagneticMomentRatio",
    /// `deuteron-proton mass ratio`: 
    DeuteronProtonMassRatio, "DeuteronProtonMassRatio",
    /// `deuteron rms charge radius`: 
    DeuteronRmsChargeRadius, "DeuteronRmsChargeRadius",
    /// `electric constant`: 
    ElectricConstant, "ElectricConstant",
    /// `Permeability of Vacuum`: 
    ElectromagneticPermeabilityOfVacuum, "ElectromagneticPermeabilityOfVacuum",
    /// `electron charge to mass quotient`: 
    ElectronChargeToMassQuotient, "ElectronChargeToMassQuotient",
    /// `electron-deuteron magnetic moment ratio`: 
    ElectronDeuteronMagneticMomentRatio, "ElectronDeuteronMagneticMomentRatio",
    /// `electron-deuteron mass ratio`: 
    ElectronDeuteronMassRatio, "ElectronDeuteronMassRatio",
    /// `electron g factor`: 
    ElectronGFactor, "ElectronGFactor",
    /// `Electron Gyromagnetic Ratio`: 
    ElectronGyromagneticRatio, "ElectronGyromagneticRatio",
    /// `electron gyromagnetic ratio over 2 pi`: 
    ElectronGyromagneticRatioOver2Pi, "ElectronGyromagneticRatioOver2Pi",
    /// `electron magnetic moment`: 
    ElectronMagneticMoment, "ElectronMagneticMoment",
    /// `electron magnetic moment anomaly`: 
    ElectronMagneticMomentAnomaly, "ElectronMagneticMomentAnomaly",
    /// `electron magnetic moment to Bohr magneton ratio`: 
    ElectronMagneticMomentToBohrMagnetonRatio, "ElectronMagneticMomentToBohrMagnetonRatio",
    /// `electron magnetic moment to nuclear magneton ratio`: 
    ElectronMagneticMomentToNuclearMagnetonRatio, "ElectronMagneticMomentToNuclearMagnetonRatio",
    /// `Electron Mass`: 
    ElectronMass, "ElectronMass",
    /// `electron mass energy equivalent`: 
    ElectronMassEnergyEquivalent, "ElectronMassEnergyEquivalent",
    /// `electron mass energy equivalent in MeV`: 
    ElectronMassEnergyEquivalentInMeV, "ElectronMassEnergyEquivalentInMeV",
    /// `electron mass in atomic mass unit`: 
    ElectronMassInAtomicMassUnit, "ElectronMassInAtomicMassUnit",
    /// `electron molar mass`: 
    ElectronMolarMass, "ElectronMolarMass",
    /// `electron-muon magnetic moment ratio`: 
    ElectronMuonMagneticMomentRatio, "ElectronMuonMagneticMomentRatio",
    /// `electron-muon mass ratio`: 
    ElectronMuonMassRatio, "ElectronMuonMassRatio",
    /// `electron-neutron magnetic moment ratio`: 
    ElectronNeutronMagneticMomentRatio, "ElectronNeutronMagneticMomentRatio",
    /// `electron-neutron mass ratio`: 
    ElectronNeutronMassRatio, "ElectronNeutronMassRatio",
    /// `electron-proton magnetic moment ratio`: 
    ElectronProtonMagneticMomentRatio, "ElectronProtonMagneticMomentRatio",
    /// `electron-proton mass ratio`: 
    ElectronProtonMassRatio, "ElectronProtonMassRatio",
    /// `electron-tau mass ratio`: 
    ElectronTauMassRatio, "ElectronTauMassRatio",
    /// `electron to alpha particle mass ratio`: 
    ElectronToAlphaParticleMassRatio, "ElectronToAlphaParticleMassRatio",
    /// `electron to shielded helion magnetic moment ratio`: 
    ElectronToShieldedHelionMagneticMomentRatio, "ElectronToShieldedHelionMagneticMomentRatio",
    /// `electron to shielded proton magnetic moment ratio`: 
    ElectronToShieldedProtonMagneticMomentRatio, "ElectronToShieldedProtonMagneticMomentRatio",
    /// `electron volt-atomic mass unit relationship`: 
    ElectronVoltAtomicMassUnitRelationship, "ElectronVoltAtomicMassUnitRelationship",
    /// `electron volt-hartree relationship`: 
    ElectronVoltHartreeRelationship, "ElectronVoltHartreeRelationship",
    /// `electron volt-hertz relationship`: 
    ElectronVoltHertzRelationship, "ElectronVoltHertzRelationship",
    /// `electron volt-inverse meter relationship`: 
    ElectronVoltInverseMeterRelationship, "ElectronVoltInverseMeterRelationship",
    /// `electron volt-joule relationship`: 
    ElectronVoltJouleRelationship, "ElectronVoltJouleRelationship",
    /// `electron volt-kelvin relationship`: 
    ElectronVoltKelvinRelationship, "ElectronVoltKelvinRelationship",
    /// `electron volt-kilogram relationship`: 
    ElectronVoltKilogramRelationship, "ElectronVoltKilogramRelationship",
    /// `Elementary Charge`: 
    ElementaryCharge, "ElementaryCharge",
    /// `elementary charge over h`: 
    ElementaryChargeOverH, "ElementaryChargeOverH",
    /// `Faraday constant`: 
    FaradayConstant, "FaradayConstant",
    /// `Fermi coupling constant`: 
    FermiCouplingConstant, "FermiCouplingConstant",
    /// `Fine-Structure Constant`: 
    FineStructureConstant, "FineStructureConstant",
    /// `first radiation constant`: 
    FirstRadiationConstant, "FirstRadiationConstant",
    /// `first radiation constant for spectral radiance`: 
    FirstRadiationConstantForSpectralRadiance, "FirstRadiationConstantForSpectralRadiance",
    /// `Gravitational constant`: 
    GravitationalConstant, "GravitationalConstant",
    /// `hartree-atomic mass unit relationship`: 
    HartreeAtomicMassUnitRelationship, "HartreeAtomicMassUnitRelationship",
    /// `hartree-electron volt relationship`: 
    HartreeElectronVoltRelationship, "HartreeElectronVoltRelationship",
    /// `Hartree Energy`: 
    HartreeEnergy, "HartreeEnergy",
    /// `Hartree energy in eV`: 
    HartreeEnergyInEV, "HartreeEnergyInEV",
    /// `hartree-hertz relationship`: 
    HartreeHertzRelationship, "HartreeHertzRelationship",
    /// `hartree-inverse meter relationship`: 
    HartreeInverseMeterRelationship, "HartreeInverseMeterRelationship",
    /// `hartree-joule relationship`: 
    HartreeJouleRelationship, "HartreeJouleRelationship",
    /// `hartree-kelvin relationship`: 
    HartreeKelvinRelationship, "HartreeKelvinRelationship",
    /// `hartree-kilogram relationship`: 
    HartreeKilogramRelationship, "HartreeKilogramRelationship",
    /// `helion-electron mass ratio`: 
    HelionElectronMassRatio, "HelionElectronMassRatio",
    /// `helion mass`: 
    HelionMass, "HelionMass",
    /// `helion mass energy equivalent`: 
    HelionMassEnergyEquivalent, "HelionMassEnergyEquivalent",
    /// `helion mass energy equivalent in MeV`: 
    HelionMassEnergyEquivalentInMeV, "HelionMassEnergyEquivalentInMeV",
    /// `helion mass in atomic mass unit`: 
    HelionMassInAtomicMassUnit, "HelionMassInAtomicMassUnit",
    /// `helion molar mass`: 
    HelionMolarMass, "HelionMolarMass",
    /// `helion-proton mass ratio`: 
    HelionProtonMassRatio, "HelionProtonMassRatio",
    /// `hertz-atomic mass unit relationship`: 
    HertzAtomicMassUnitRelationship, "HertzAtomicMassUnitRelationship",
    /// `hertz-electron volt relationship`: 
    HertzElectronVoltRelationship, "HertzElectronVoltRelationship",
    /// `hertz-hartree relationship`: 
    HertzHartreeRelationship, "HertzHartreeRelationship",
    /// `hertz-inverse meter relationship`: 
    HertzInverseMeterRelationship, "HertzInverseMeterRelationship",
    /// `hertz-joule relationship`: 
    HertzJouleRelationship, "HertzJouleRelationship",
    /// `hertz-kelvin relationship`: 
    HertzKelvinRelationship, "HertzKelvinRelationship",
    /// `hertz-kilogram relationship`: 
    HertzKilogramRelationship, "HertzKilogramRelationship",
    /// `inverse fine-structure constant`: 
    InverseFineStructureConstant, "InverseFineStructureConstant",
    /// `inverse meter-atomic mass unit relationship`: 
    InverseMeterAtomicMassUnitRelationship, "InverseMeterAtomicMassUnitRelationship",
    /// `inverse meter-electron volt relationship`: 
    InverseMeterElectronVoltRelationship, "InverseMeterElectronVoltRelationship",
    /// `inverse meter-hartree relationship`: 
    InverseMeterHartreeRelationship, "InverseMeterHartreeRelationship",
    /// `inverse meter-hertz relationship`: 
    InverseMeterHertzRelationship, "InverseMeterHertzRelationship",
    /// `inverse meter-joule relationship`: 
    InverseMeterJouleRelationship, "InverseMeterJouleRelationship",
    /// `inverse meter-kelvin relationship`: 
    InverseMeterKelvinRelationship, "InverseMeterKelvinRelationship",
    /// `inverse meter-kilogram relationship`: 
    InverseMeterKilogramRelationship, "InverseMeterKilogramRelationship",
    /// `inverse of conductance quantum`: 
    InverseOfConductanceQuantum, "InverseOfConductanceQuantum",
    /// `Josephson Constant`: 
    JosephsonConstant, "JosephsonConstant",
    /// `joule-atomic mass unit relationship`: 
    JouleAtomicMassUnitRelationship, "JouleAtomicMassUnitRelationship",
    /// `joule-electron volt relationship`: 
    JouleElectronVoltRelationship, "JouleElectronVoltRelationship",
    /// `joule-hartree relationship`: 
    JouleHartreeRelationship, "JouleHartreeRelationship",
    /// `joule-hertz relationship`: 
    JouleHertzRelationship, "JouleHertzRelationship",
    /// `joule-inverse meter relationship`: 
    JouleInverseMeterRelationship, "JouleInverseMeterRelationship",
    /// `joule-kelvin relationship`: 
    JouleKelvinRelationship, "JouleKelvinRelationship",
    /// `joule-kilogram relationship`: 
    JouleKilogramRelationship, "JouleKilogramRelationship",
    /// `kelvin-atomic mass unit relationship`: 
    KelvinAtomicMassUnitRelationship, "KelvinAtomicMassUnitRelationship",
    /// `kelvin-electron volt relationship`: 
    KelvinElectronVoltRelationship, "KelvinElectronVoltRelationship",
    /// `kelvin-hartree relationship`: 
    KelvinHartreeRelationship, "KelvinHartreeRelationship",
    /// `kelvin-hertz relationship`: 
    KelvinHertzRelationship, "KelvinHertzRelationship",
    /// `kelvin-inverse meter relationship`: 
    KelvinInverseMeterRelationship, "KelvinInverseMeterRelationship",
    /// `kelvin-joule relationship`: 
    KelvinJouleRelationship, "KelvinJouleRelationship",
    /// `kelvin-kilogram relationship`: 
    KelvinKilogramRelationship, "KelvinKilogramRelationship",
    /// `kilogram-atomic mass unit relationship`: 
    KilogramAtomicMassUnitRelationship, "KilogramAtomicMassUnitRelationship",
    /// `kilogram-electron volt relationship`: 
    KilogramElectronVoltRelationship, "KilogramElectronVoltRelationship",
    /// `kilogram-hartree relationship`: 
    KilogramHartreeRelationship, "KilogramHartreeRelationship",
    /// `kilogram-hertz relationship`: 
    KilogramHertzRelationship, "KilogramHertzRelationship",
    /// `kilogram-inverse meter relationship`: 
    KilogramInverseMeterRelationship, "KilogramInverseMeterRelationship",
    /// `Kilogram-Joule Relationship`: 
    KilogramJouleRelationship, "KilogramJouleRelationship",
    /// `kilogram-kelvin relationship`: 
    KilogramKelvinRelationship, "KilogramKelvinRelationship",
    /// `lattice parameter of silicon`: 
    LatticeParameterOfSilicon, "LatticeParameterOfSilicon",
    /// `lattice spacing of silicon`: 
    LatticeSpacingOfSilicon, "LatticeSpacingOfSilicon",
    /// `Loschmidt constant 273.15 K 101.325 kPa`: 
    LoschmidtConstant273_15K101_325KPa, "LoschmidtConstant273.15K101.325KPa",
    /// `Magnetic Constant`: 
    MagneticConstant, "MagneticConstant",
    /// `magnetic flux quantum`: 
    MagneticFluxQuantum, "MagneticFluxQuantum",
    /// `Mo x unit`: 
    MoXUnit, "MoXUnit",
    /// `molar gas constant`: 
    MolarGasConstant, "MolarGasConstant",
    /// `molar mass constant`: 
    MolarMassConstant, "MolarMassConstant",
    /// `molar mass of carbon-12`: 
    MolarMassOfCarbon12, "MolarMassOfCarbon12",
    /// `molar Planck constant`: 
    MolarPlanckConstant, "MolarPlanckConstant",
    /// `molar Planck constant times c`: 
    MolarPlanckConstantTimesC, "MolarPlanckConstantTimesC",
    /// `molar volume of ideal gas 273.15 K 100 kPa`: 
    MolarVolumeOfIdealGas273_15K100KPa, "MolarVolumeOfIdealGas273.15K100KPa",
    /// `molar volume of ideal gas 273.15 K 101.325 kPa`: 
    MolarVolumeOfIdealGas273_15K101_325KPa, "MolarVolumeOfIdealGas273.15K101.325KPa",
    /// `molar volume of silicon`: 
    MolarVolumeOfSilicon, "MolarVolumeOfSilicon",
    /// `muon Compton wavelength`: 
    MuonComptonWavelength, "MuonComptonWavelength",
    /// `muon Compton wavelength over 2 pi`: 
    MuonComptonWavelengthOver2Pi, "MuonComptonWavelengthOver2Pi",
    /// `muon-electron mass ratio`: 
    MuonElectronMassRatio, "MuonElectronMassRatio",
    /// `muon g factor`: 
    MuonGFactor, "MuonGFactor",
    /// `muon magnetic moment`: 
    MuonMagneticMoment, "MuonMagneticMoment",
    /// `muon magnetic moment anomaly`: 
    MuonMagneticMomentAnomaly, "MuonMagneticMomentAnomaly",
    /// `muon magnetic moment to Bohr magneton ratio`: 
    MuonMagneticMomentToBohrMagnetonRatio, "MuonMagneticMomentToBohrMagnetonRatio",
    /// `muon magnetic moment to nuclear magneton ratio`: 
    MuonMagneticMomentToNuclearMagnetonRatio, "MuonMagneticMomentToNuclearMagnetonRatio",
    /// `muon mass`: 
    MuonMass, "MuonMass",
    /// `muon mass energy equivalent`: 
    MuonMassEnergyEquivalent, "MuonMassEnergyEquivalent",
    /// `muon mass energy equivalent in MeV`: 
    MuonMassEnergyEquivalentInMeV, "MuonMassEnergyEquivalentInMeV",
    /// `muon mass in atomic mass unit`: 
    MuonMassInAtomicMassUnit, "MuonMassInAtomicMassUnit",
    /// `muon molar mass`: 
    MuonMolarMass, "MuonMolarMass",
    /// `muon-neutron mass ratio`: 
    MuonNeutronMassRatio, "MuonNeutronMassRatio",
    /// `muon-proton magnetic moment ratio`: 
    MuonProtonMagneticMomentRatio, "MuonProtonMagneticMomentRatio",
    /// `muon-proton mass ratio`: 
    MuonProtonMassRatio, "MuonProtonMassRatio",
    /// `muon-tau mass ratio`: 
    MuonTauMassRatio, "MuonTauMassRatio",
    /// `natural unit of action`: 
    NaturalUnitOfAction, "NaturalUnitOfAction",
    /// `natural unit of action in eV s`: 
    NaturalUnitOfActionInEVS, "NaturalUnitOfActionInEVS",
    /// `natural unit of energy`: 
    NaturalUnitOfEnergy, "NaturalUnitOfEnergy",
    /// `natural unit of energy in MeV`: 
    NaturalUnitOfEnergyInMeV, "NaturalUnitOfEnergyInMeV",
    /// `natural unit of length`: 
    NaturalUnitOfLength, "NaturalUnitOfLength",
    /// `natural unit of mass`: 
    NaturalUnitOfMass, "NaturalUnitOfMass",
    /// `natural unit of momentum`: 
    NaturalUnitOfMomentum, "NaturalUnitOfMomentum",
    /// `natural unit of momentum in MeV PER c`: 
    NaturalUnitOfMomentumInMeV_PER_c, "NaturalUnitOfMomentumInMeV-PER-c",
    /// `natural unit of time`: 
    NaturalUnitOfTime, "NaturalUnitOfTime",
    /// `natural unit of velocity`: 
    NaturalUnitOfVelocity, "NaturalUnitOfVelocity",
    /// `neutron Compton wavelength`: 
    NeutronComptonWavelength, "NeutronComptonWavelength",
    /// `neutron Compton wavelength over 2 pi`: 
    NeutronComptonWavelengthOver2Pi, "NeutronComptonWavelengthOver2Pi",
    /// `neutron-electron magnetic moment ratio`: 
    NeutronElectronMagneticMomentRatio, "NeutronElectronMagneticMomentRatio",
    /// `neutron-electron mass ratio`: 
    NeutronElectronMassRatio, "NeutronElectronMassRatio",
    /// `neutron g factor`: 
    NeutronGFactor, "NeutronGFactor",
    /// `neutron gyromagnetic ratio`: 
    NeutronGyromagneticRatio, "NeutronGyromagneticRatio",
    /// `neutron gyromagnetic ratio over 2 pi`: 
    NeutronGyromagneticRatioOver2Pi, "NeutronGyromagneticRatioOver2Pi",
    /// `neutron magnetic moment`: 
    NeutronMagneticMoment, "NeutronMagneticMoment",
    /// `neutron magnetic moment to Bohr magneton ratio`: 
    NeutronMagneticMomentToBohrMagnetonRatio, "NeutronMagneticMomentToBohrMagnetonRatio",
    /// `neutron magnetic moment to nuclear magneton ratio`: 
    NeutronMagneticMomentToNuclearMagnetonRatio, "NeutronMagneticMomentToNuclearMagnetonRatio",
    /// `neutron mass`: 
    NeutronMass, "NeutronMass",
    /// `neutron mass energy equivalent`: 
    NeutronMassEnergyEquivalent, "NeutronMassEnergyEquivalent",
    /// `neutron mass energy equivalent in MeV`: 
    NeutronMassEnergyEquivalentInMeV, "NeutronMassEnergyEquivalentInMeV",
    /// `neutron mass in atomic mass unit`: 
    NeutronMassInAtomicMassUnit, "NeutronMassInAtomicMassUnit",
    /// `neutron molar mass`: 
    NeutronMolarMass, "NeutronMolarMass",
    /// `neutron-muon mass ratio`: 
    NeutronMuonMassRatio, "NeutronMuonMassRatio",
    /// `neutron-proton magnetic moment ratio`: 
    NeutronProtonMagneticMomentRatio, "NeutronProtonMagneticMomentRatio",
    /// `neutron-proton mass ratio`: 
    NeutronProtonMassRatio, "NeutronProtonMassRatio",
    /// `neutron-tau mass ratio`: 
    NeutronTauMassRatio, "NeutronTauMassRatio",
    /// `neutron to shielded proton magnetic moment ratio`: 
    NeutronToShieldedProtonMagneticMomentRatio, "NeutronToShieldedProtonMagneticMomentRatio",
    /// `Newtonian constant of gravitation`: 
    NewtonianConstantOfGravitation, "NewtonianConstantOfGravitation",
    /// `Nuclear Magneton`: 
    NuclearMagneton, "NuclearMagneton",
    /// `nuclear magneton in eV per T`: 
    NuclearMagnetonInEVPerT, "NuclearMagnetonInEVPerT",
    /// `nuclear magneton in inverse meters per tesla`: 
    NuclearMagnetonInInverseMetersPerTesla, "NuclearMagnetonInInverseMetersPerTesla",
    /// `nuclear magneton in K per T`: 
    NuclearMagnetonInKPerT, "NuclearMagnetonInKPerT",
    /// `nuclear magneton in MHz per T`: 
    NuclearMagnetonInMHzPerT, "NuclearMagnetonInMHzPerT",
    /// `Permittivity of Vacuum`: 
    PermittivityOfVacuum, "PermittivityOfVacuum",
    /// `Planck Constant`: 
    PlanckConstant, "PlanckConstant",
    /// `Planck constant in eV s`: 
    PlanckConstantInEVS, "PlanckConstantInEVS",
    /// `Planck constant over 2 pi`: 
    PlanckConstantOver2Pi, "PlanckConstantOver2Pi",
    /// `Planck constant over 2 pi in eV s`: 
    PlanckConstantOver2PiInEVS, "PlanckConstantOver2PiInEVS",
    /// `Planck constant over 2 pi times c in MeV fm`: 
    PlanckConstantOver2PiTimesCInMeVFm, "PlanckConstantOver2PiTimesCInMeVFm",
    /// `Planck length`: 
    PlanckLength, "PlanckLength",
    /// `Planck mass`: 
    PlanckMass, "PlanckMass",
    /// `Planck mass energy equivalent in GeV`: 
    PlanckMassEnergyEquivalentInGeV, "PlanckMassEnergyEquivalentInGeV",
    /// `Planck temperature`: 
    PlanckTemperature, "PlanckTemperature",
    /// `Planck time`: 
    PlanckTime, "PlanckTime",
    /// `proton charge to mass quotient`: 
    ProtonChargeToMassQuotient, "ProtonChargeToMassQuotient",
    /// `proton Compton wavelength`: 
    ProtonComptonWavelength, "ProtonComptonWavelength",
    /// `proton Compton wavelength over 2 pi`: 
    ProtonComptonWavelengthOver2Pi, "ProtonComptonWavelengthOver2Pi",
    /// `proton-electron mass ratio`: 
    ProtonElectronMassRatio, "ProtonElectronMassRatio",
    /// `proton g factor`: 
    ProtonGFactor, "ProtonGFactor",
    /// `proton gyromagnetic ratio`: 
    ProtonGyromagneticRatio, "ProtonGyromagneticRatio",
    /// `proton gyromagnetic ratio over 2 pi`: 
    ProtonGyromagneticRatioOver2Pi, "ProtonGyromagneticRatioOver2Pi",
    /// `proton magnetic moment`: 
    ProtonMagneticMoment, "ProtonMagneticMoment",
    /// `proton magnetic moment to Bohr magneton ratio`: 
    ProtonMagneticMomentToBohrMagnetonRatio, "ProtonMagneticMomentToBohrMagnetonRatio",
    /// `proton magnetic moment to nuclear magneton ratio`: 
    ProtonMagneticMomentToNuclearMagnetonRatio, "ProtonMagneticMomentToNuclearMagnetonRatio",
    /// `proton mag. shielding correction`: 
    ProtonMagneticShieldingCorrection, "ProtonMagneticShieldingCorrection",
    /// `proton mass`: 
    ProtonMass, "ProtonMass",
    /// `proton mass energy equivalent`: 
    ProtonMassEnergyEquivalent, "ProtonMassEnergyEquivalent",
    /// `proton mass energy equivalent in MeV`: 
    ProtonMassEnergyEquivalentInMeV, "ProtonMassEnergyEquivalentInMeV",
    /// `proton mass in atomic mass unit`: 
    ProtonMassInAtomicMassUnit, "ProtonMassInAtomicMassUnit",
    /// `proton molar mass`: 
    ProtonMolarMass, "ProtonMolarMass",
    /// `proton-muon mass ratio`: 
    ProtonMuonMassRatio, "ProtonMuonMassRatio",
    /// `proton-neutron magnetic moment ratio`: 
    ProtonNeutronMagneticMomentRatio, "ProtonNeutronMagneticMomentRatio",
    /// `proton-neutron mass ratio`: 
    ProtonNeutronMassRatio, "ProtonNeutronMassRatio",
    /// `proton rms charge radius`: 
    ProtonRmsChargeRadius, "ProtonRmsChargeRadius",
    /// `proton-tau mass ratio`: 
    ProtonTauMassRatio, "ProtonTauMassRatio",
    /// `quantum of circulation`: 
    QuantumOfCirculation, "QuantumOfCirculation",
    /// `quantum of circulation times 2`: 
    QuantumOfCirculationTimes2, "QuantumOfCirculationTimes2",
    /// `Reduced Planck Constant`: 
    ReducedPlanckConstant, "ReducedPlanckConstant",
    /// `Rydberg constant`: 
    RydbergConstant, "RydbergConstant",
    /// `Rydberg constant times c in Hz`: 
    RydbergConstantTimesCInHz, "RydbergConstantTimesCInHz",
    /// `Rydberg constant times hc in eV`: 
    RydbergConstantTimesHcInEV, "RydbergConstantTimesHcInEV",
    /// `Rydberg constant times hc in J`: 
    RydbergConstantTimesHcInJ, "RydbergConstantTimesHcInJ",
    /// `Sackur-Tetrode constant 1 K 100 kPa`: 
    SackurTetrodeConstant1K100KPa, "SackurTetrodeConstant1K100KPa",
    /// `Sackur-Tetrode constant 1 K 101.325 kPa`: 
    SackurTetrodeConstant1K101_325KPa, "SackurTetrodeConstant1K101.325KPa",
    /// `second radiation constant`: 
    SecondRadiationConstant, "SecondRadiationConstant",
    /// `shielded helion gyromagnetic ratio`: 
    ShieldedHelionGyromagneticRatio, "ShieldedHelionGyromagneticRatio",
    /// `shielded helion gyromagnetic ratio over 2 pi`: 
    ShieldedHelionGyromagneticRatioOver2Pi, "ShieldedHelionGyromagneticRatioOver2Pi",
    /// `shielded helion magnetic moment`: 
    ShieldedHelionMagneticMoment, "ShieldedHelionMagneticMoment",
    /// `shielded helion magnetic moment to Bohr magneton ratio`: 
    ShieldedHelionMagneticMomentToBohrMagnetonRatio, "ShieldedHelionMagneticMomentToBohrMagnetonRatio",
    /// `shielded helion magnetic moment to nuclear magneton ratio`: 
    ShieldedHelionMagneticMomentToNuclearMagnetonRatio, "ShieldedHelionMagneticMomentToNuclearMagnetonRatio",
    /// `shielded helion to proton magnetic moment ratio`: 
    ShieldedHelionToProtonMagneticMomentRatio, "ShieldedHelionToProtonMagneticMomentRatio",
    /// `shielded helion to shielded proton magnetic moment ratio`: 
    ShieldedHelionToShieldedProtonMagneticMomentRatio, "ShieldedHelionToShieldedProtonMagneticMomentRatio",
    /// `shielded proton gyromagnetic ratio`: 
    ShieldedProtonGyromagneticRatio, "ShieldedProtonGyromagneticRatio",
    /// `shielded proton gyromagnetic ratio over 2 pi`: 
    ShieldedProtonGyromagneticRatioOver2Pi, "ShieldedProtonGyromagneticRatioOver2Pi",
    /// `shielded proton magnetic moment`: 
    ShieldedProtonMagneticMoment, "ShieldedProtonMagneticMoment",
    /// `shielded proton magnetic moment to Bohr magneton ratio`: 
    ShieldedProtonMagneticMomentToBohrMagnetonRatio, "ShieldedProtonMagneticMomentToBohrMagnetonRatio",
    /// `shielded proton magnetic moment to nuclear magneton ratio`: 
    ShieldedProtonMagneticMomentToNuclearMagnetonRatio, "ShieldedProtonMagneticMomentToNuclearMagnetonRatio",
    /// `Speed of Light (vacuum)`: 
    SpeedOfLight_Vacuum, "SpeedOfLight_Vacuum",
    /// `standard acceleration of gravity`: 
    StandardAccelerationOfGravity, "StandardAccelerationOfGravity",
    /// `standard atmosphere`: 
    StandardAtmosphere, "StandardAtmosphere",
    /// `Stefan-Boltzmann Constant`: 
    StefanBoltzmannConstant, "StefanBoltzmannConstant",
    /// `tau Compton wavelength`: 
    TauComptonWavelength, "TauComptonWavelength",
    /// `tau Compton wavelength over 2 pi`: 
    TauComptonWavelengthOver2Pi, "TauComptonWavelengthOver2Pi",
    /// `tau-electron mass ratio`: 
    TauElectronMassRatio, "TauElectronMassRatio",
    /// `tau mass`: 
    TauMass, "TauMass",
    /// `tau mass energy equivalent`: 
    TauMassEnergyEquivalent, "TauMassEnergyEquivalent",
    /// `tau mass energy equivalent in MeV`: 
    TauMassEnergyEquivalentInMeV, "TauMassEnergyEquivalentInMeV",
    /// `tau mass in atomic mass unit`: 
    TauMassInAtomicMassUnit, "TauMassInAtomicMassUnit",
    /// `tau molar mass`: 
    TauMolarMass, "TauMolarMass",
    /// `tau-muon mass ratio`: 
    TauMuonMassRatio, "TauMuonMassRatio",
    /// `tau-neutron mass ratio`: 
    TauNeutronMassRatio, "TauNeutronMassRatio",
    /// `tau-proton mass ratio`: 
    TauProtonMassRatio, "TauProtonMassRatio",
    /// `Thomson cross section`: 
    ThomsonCrossSection, "ThomsonCrossSection",
    /// `triton-electron magnetic moment ratio`: 
    TritonElectronMagneticMomentRatio, "TritonElectronMagneticMomentRatio",
    /// `triton-electron mass ratio`: 
    TritonElectronMassRatio, "TritonElectronMassRatio",
    /// `triton g factor`: 
    TritonGFactor, "TritonGFactor",
    /// `triton magnetic moment`: 
    TritonMagneticMoment, "TritonMagneticMoment",
    /// `triton magnetic moment to Bohr magneton ratio`: 
    TritonMagneticMomentToBohrMagnetonRatio, "TritonMagneticMomentToBohrMagnetonRatio",
    /// `triton magnetic moment to nuclear magneton ratio`: 
    TritonMagneticMomentToNuclearMagnetonRatio, "TritonMagneticMomentToNuclearMagnetonRatio",
    /// `triton mass`: 
    TritonMass, "TritonMass",
    /// `triton mass energy equivalent`: 
    TritonMassEnergyEquivalent, "TritonMassEnergyEquivalent",
    /// `triton mass energy equivalent in MeV`: 
    TritonMassEnergyEquivalentInMeV, "TritonMassEnergyEquivalentInMeV",
    /// `triton mass in atomic mass unit`: 
    TritonMassInAtomicMassUnit, "TritonMassInAtomicMassUnit",
    /// `triton molar mass`: 
    TritonMolarMass, "TritonMolarMass",
    /// `triton-neutron magnetic moment ratio`: 
    TritonNeutronMagneticMomentRatio, "TritonNeutronMagneticMomentRatio",
    /// `triton-proton magnetic moment ratio`: 
    TritonProtonMagneticMomentRatio, "TritonProtonMagneticMomentRatio",
    /// `triton-proton mass ratio`: 
    TritonProtonMassRatio, "TritonProtonMassRatio",
    /// `unified atomic mass unit`: 
    UnifiedAtomicMassUnit, "UnifiedAtomicMassUnit",
    /// `Value for electron volt`: 
    ValueForElectronVolt, "ValueForElectronVolt",
    /// `Value for alpha particle-electron mass ratio`: 
    Value_AlphaParticleElectronMassRatio, "Value_AlphaParticleElectronMassRatio",
    /// `Value for alpha particle mass`: 
    Value_AlphaParticleMass, "Value_AlphaParticleMass",
    /// `Value for alpha particle mass energy equivalent`: 
    Value_AlphaParticleMassEnergyEquivalent, "Value_AlphaParticleMassEnergyEquivalent",
    /// `Value for alpha particle mass energy equivalent in MeV`: 
    Value_AlphaParticleMassEnergyEquivalentInMeV, "Value_AlphaParticleMassEnergyEquivalentInMeV",
    /// `Value for alpha particle mass in atomic mass unit`: 
    Value_AlphaParticleMassInAtomicMassUnit, "Value_AlphaParticleMassInAtomicMassUnit",
    /// `Value for alpha particle molar mass`: 
    Value_AlphaParticleMolarMass, "Value_AlphaParticleMolarMass",
    /// `Value for alpha particle-proton mass ratio`: 
    Value_AlphaParticleProtonMassRatio, "Value_AlphaParticleProtonMassRatio",
    /// `Value for Angstrom star`: 
    Value_AngstromStar, "Value_AngstromStar",
    /// `Value for atomic mass constant`: 
    Value_AtomicMassConstant, "Value_AtomicMassConstant",
    /// `Value for atomic mass constant energy equivalent`: 
    Value_AtomicMassConstantEnergyEquivalent, "Value_AtomicMassConstantEnergyEquivalent",
    /// `Value for atomic mass constant energy equivalent in MeV`: 
    Value_AtomicMassConstantEnergyEquivalentInMeV, "Value_AtomicMassConstantEnergyEquivalentInMeV",
    /// `Value for atomic mass unit-electron volt relationship`: 
    Value_AtomicMassUnitElectronVoltRelationship, "Value_AtomicMassUnitElectronVoltRelationship",
    /// `Value for atomic mass unit-hartree relationship`: 
    Value_AtomicMassUnitHartreeRelationship, "Value_AtomicMassUnitHartreeRelationship",
    /// `Value for atomic mass unit-hertz relationship`: 
    Value_AtomicMassUnitHertzRelationship, "Value_AtomicMassUnitHertzRelationship",
    /// `Value for atomic mass unit-inverse meter relationship`: 
    Value_AtomicMassUnitInverseMeterRelationship, "Value_AtomicMassUnitInverseMeterRelationship",
    /// `Value for atomic mass unit-joule relationship`: 
    Value_AtomicMassUnitJouleRelationship, "Value_AtomicMassUnitJouleRelationship",
    /// `Value for atomic mass unit-kelvin relationship`: 
    Value_AtomicMassUnitKelvinRelationship, "Value_AtomicMassUnitKelvinRelationship",
    /// `Value for atomic mass unit-kilogram relationship`: 
    Value_AtomicMassUnitKilogramRelationship, "Value_AtomicMassUnitKilogramRelationship",
    /// `Value for atomic unit of 1st hyperpolarizability`: 
    Value_AtomicUnitOf1stHyperpolarizability, "Value_AtomicUnitOf1stHyperpolarizability",
    /// `Value for atomic unit of 2nd hyperpolarizability`: 
    Value_AtomicUnitOf2ndHyperpolarizability, "Value_AtomicUnitOf2ndHyperpolarizability",
    /// `Value for atomic unit of action`: 
    Value_AtomicUnitOfAction, "Value_AtomicUnitOfAction",
    /// `Value for atomic unit of charge`: 
    Value_AtomicUnitOfCharge, "Value_AtomicUnitOfCharge",
    /// `Value for atomic unit of charge density`: 
    Value_AtomicUnitOfChargeDensity, "Value_AtomicUnitOfChargeDensity",
    /// `Value for atomic unit of current`: 
    Value_AtomicUnitOfCurrent, "Value_AtomicUnitOfCurrent",
    /// `Value for atomic unit of electric dipole mom.`: 
    Value_AtomicUnitOfElectricDipoleMoment, "Value_AtomicUnitOfElectricDipoleMoment",
    /// `Value for atomic unit of electric field`: 
    Value_AtomicUnitOfElectricField, "Value_AtomicUnitOfElectricField",
    /// `Value for atomic unit of electric field gradient`: 
    Value_AtomicUnitOfElectricFieldGradient, "Value_AtomicUnitOfElectricFieldGradient",
    /// `Value for atomic unit of electric polarizability`: 
    Value_AtomicUnitOfElectricPolarizability, "Value_AtomicUnitOfElectricPolarizability",
    /// `Value for atomic unit of electric potential`: 
    Value_AtomicUnitOfElectricPotential, "Value_AtomicUnitOfElectricPotential",
    /// `Value for atomic unit of electric quadrupole moment`: 
    Value_AtomicUnitOfElectricQuadrupoleMoment, "Value_AtomicUnitOfElectricQuadrupoleMoment",
    /// `Value for atomic unit of energy`: 
    Value_AtomicUnitOfEnergy, "Value_AtomicUnitOfEnergy",
    /// `Value for atomic unit of force`: 
    Value_AtomicUnitOfForce, "Value_AtomicUnitOfForce",
    /// `Value for atomic unit of length`: 
    Value_AtomicUnitOfLength, "Value_AtomicUnitOfLength",
    /// `Value for atomic unit of magnetic dipole moment`: 
    Value_AtomicUnitOfMagneticDipoleMoment, "Value_AtomicUnitOfMagneticDipoleMoment",
    /// `Value for atomic unit of magnetic flux density`: 
    Value_AtomicUnitOfMagneticFluxDensity, "Value_AtomicUnitOfMagneticFluxDensity",
    /// `Value for atomic unit of magnetizability`: 
    Value_AtomicUnitOfMagnetizability, "Value_AtomicUnitOfMagnetizability",
    /// `Value for atomic unit of mass`: 
    Value_AtomicUnitOfMass, "Value_AtomicUnitOfMass",
    /// `Value for atomic unit of momentum`: 
    Value_AtomicUnitOfMomentum, "Value_AtomicUnitOfMomentum",
    /// `Value for atomic unit of permittivity`: 
    Value_AtomicUnitOfPermittivity, "Value_AtomicUnitOfPermittivity",
    /// `Value for atomic unit of time`: 
    Value_AtomicUnitOfTime, "Value_AtomicUnitOfTime",
    /// `Value for atomic unit of velocity`: 
    Value_AtomicUnitOfVelocity, "Value_AtomicUnitOfVelocity",
    /// `Value for Avogadro constant`: 
    Value_AvogadroConstant, "Value_AvogadroConstant",
    /// `Value for Bohr magneton`: 
    Value_BohrMagneton, "Value_BohrMagneton",
    /// `Value for Bohr magneton in eV per T`: 
    Value_BohrMagnetonInEVPerT, "Value_BohrMagnetonInEVPerT",
    /// `Value for Bohr magneton in Hz perT`: 
    Value_BohrMagnetonInHzPerT, "Value_BohrMagnetonInHzPerT",
    /// `Value for Bohr magneton in inverse meters per tesla`: 
    Value_BohrMagnetonInInverseMetersPerTesla, "Value_BohrMagnetonInInverseMetersPerTesla",
    /// `Value for Bohr magneton in K per T`: 
    Value_BohrMagnetonInKPerT, "Value_BohrMagnetonInKPerT",
    /// `Value for Bohr radius`: 
    Value_BohrRadius, "Value_BohrRadius",
    /// `Value for Boltzmann constant`: 
    Value_BoltzmannConstant, "Value_BoltzmannConstant",
    /// `Value for Boltzmann constant in eV per K`: 
    Value_BoltzmannConstantInEVPerK, "Value_BoltzmannConstantInEVPerK",
    /// `Value for Boltzmann constant in Hz per K`: 
    Value_BoltzmannConstantInHzPerK, "Value_BoltzmannConstantInHzPerK",
    /// `Value for Boltzmann constant in inverse meters per kelvin`: 
    Value_BoltzmannConstantInInverseMetersPerKelvin, "Value_BoltzmannConstantInInverseMetersPerKelvin",
    /// `Value for characteristic impedance of vacuum`: 
    Value_CharacteristicImpedanceOfVacuum, "Value_CharacteristicImpedanceOfVacuum",
    /// `Value for classical electron radius`: 
    Value_ClassicalElectronRadius, "Value_ClassicalElectronRadius",
    /// `Value for Compton wavelength`: 
    Value_ComptonWavelength, "Value_ComptonWavelength",
    /// `Value for Compton wavelength over 2 pi`: 
    Value_ComptonWavelengthOver2Pi, "Value_ComptonWavelengthOver2Pi",
    /// `Value for conductance quantum`: 
    Value_ConductanceQuantum, "Value_ConductanceQuantum",
    /// `Value for conventional value of Josephson constant`: 
    Value_ConventionalValueOfJosephsonConstant, "Value_ConventionalValueOfJosephsonConstant",
    /// `Value for conventional value of von Klitzing constant`: 
    Value_ConventionalValueOfVonKlitzingConstant, "Value_ConventionalValueOfVonKlitzingConstant",
    /// `Value for Cu x unit`: 
    Value_CuXUnit, "Value_CuXUnit",
    /// `Value for deuteron-electron magnetic moment ratio`: 
    Value_DeuteronElectronMagneticMomentRatio, "Value_DeuteronElectronMagneticMomentRatio",
    /// `Value for deuteron-electron mass ratio`: 
    Value_DeuteronElectronMassRatio, "Value_DeuteronElectronMassRatio",
    /// `Value for deuteron g factor`: 
    Value_DeuteronGFactor, "Value_DeuteronGFactor",
    /// `Value for deuteron magnetic moment`: 
    Value_DeuteronMagneticMoment, "Value_DeuteronMagneticMoment",
    /// `Value for deuteron magnetic moment to Bohr magneton ratio`: 
    Value_DeuteronMagneticMomentToBohrMagnetonRatio, "Value_DeuteronMagneticMomentToBohrMagnetonRatio",
    /// `Value for deuteron magnetic moment to nuclear magneton ratio`: 
    Value_DeuteronMagneticMomentToNuclearMagnetonRatio, "Value_DeuteronMagneticMomentToNuclearMagnetonRatio",
    /// `Value for deuteron mass`: 
    Value_DeuteronMass, "Value_DeuteronMass",
    /// `Value for deuteron mass energy equivalent`: 
    Value_DeuteronMassEnergyEquivalent, "Value_DeuteronMassEnergyEquivalent",
    /// `Value for deuteron mass energy equivalent in MeV`: 
    Value_DeuteronMassEnergyEquivalentInMeV, "Value_DeuteronMassEnergyEquivalentInMeV",
    /// `Deuteron Mass (amu)`: 
    Value_DeuteronMassInAtomicMassUnit, "Value_DeuteronMassInAtomicMassUnit",
    /// `Value for deuteron molar mass`: 
    Value_DeuteronMolarMass, "Value_DeuteronMolarMass",
    /// `Value for deuteron-neutron magnetic moment ratio`: 
    Value_DeuteronNeutronMagneticMomentRatio, "Value_DeuteronNeutronMagneticMomentRatio",
    /// `Value for deuteron-proton magnetic moment ratio`: 
    Value_DeuteronProtonMagneticMomentRatio, "Value_DeuteronProtonMagneticMomentRatio",
    /// `Value for deuteron-proton mass ratio`: 
    Value_DeuteronProtonMassRatio, "Value_DeuteronProtonMassRatio",
    /// `Value for deuteron rms charge radius`: 
    Value_DeuteronRmsChargeRadius, "Value_DeuteronRmsChargeRadius",
    /// `Value for electric constant`: 
    Value_ElectricConstant, "Value_ElectricConstant",
    /// `Value for electron charge to mass quotient`: 
    Value_ElectronChargeToMassQuotient, "Value_ElectronChargeToMassQuotient",
    /// `Value for electron-deuteron magnetic moment ratio`: 
    Value_ElectronDeuteronMagneticMomentRatio, "Value_ElectronDeuteronMagneticMomentRatio",
    /// `Value for electron-deuteron mass ratio`: 
    Value_ElectronDeuteronMassRatio, "Value_ElectronDeuteronMassRatio",
    /// `Value for electron g factor`: 
    Value_ElectronGFactor, "Value_ElectronGFactor",
    /// `Value for electron gyromagnetic ratio`: 
    Value_ElectronGyromagneticRatio, "Value_ElectronGyromagneticRatio",
    /// `Value for electron gyromagnetic ratio over 2 pi`: 
    Value_ElectronGyromagneticRatioOver2Pi, "Value_ElectronGyromagneticRatioOver2Pi",
    /// `Value for electron magnetic moment`: 
    Value_ElectronMagneticMoment, "Value_ElectronMagneticMoment",
    /// `Value for electron magnetic moment anomaly`: 
    Value_ElectronMagneticMomentAnomaly, "Value_ElectronMagneticMomentAnomaly",
    /// `Value for electron magnetic moment to Bohr magneton ratio`: 
    Value_ElectronMagneticMomentToBohrMagnetonRatio, "Value_ElectronMagneticMomentToBohrMagnetonRatio",
    /// `Value for electron magnetic moment to nuclear magneton ratio`: 
    Value_ElectronMagneticMomentToNuclearMagnetonRatio, "Value_ElectronMagneticMomentToNuclearMagnetonRatio",
    /// `Value for electron mass`: 
    Value_ElectronMass, "Value_ElectronMass",
    /// `Value for electron mass energy equivalent`: 
    Value_ElectronMassEnergyEquivalent, "Value_ElectronMassEnergyEquivalent",
    /// `Value for electron mass energy equivalent in MeV`: 
    Value_ElectronMassEnergyEquivalentInMeV, "Value_ElectronMassEnergyEquivalentInMeV",
    /// `Electron Mass (amu)`: 
    Value_ElectronMassInAtomicMassUnit, "Value_ElectronMassInAtomicMassUnit",
    /// `Value for electron molar mass`: 
    Value_ElectronMolarMass, "Value_ElectronMolarMass",
    /// `Value for electron-muon magnetic moment ratio`: 
    Value_ElectronMuonMagneticMomentRatio, "Value_ElectronMuonMagneticMomentRatio",
    /// `Value for electron-muon mass ratio`: 
    Value_ElectronMuonMassRatio, "Value_ElectronMuonMassRatio",
    /// `Value for electron-neutron magnetic moment ratio`: 
    Value_ElectronNeutronMagneticMomentRatio, "Value_ElectronNeutronMagneticMomentRatio",
    /// `Value for electron-neutron mass ratio`: 
    Value_ElectronNeutronMassRatio, "Value_ElectronNeutronMassRatio",
    /// `Value for electron-proton magnetic moment ratio`: 
    Value_ElectronProtonMagneticMomentRatio, "Value_ElectronProtonMagneticMomentRatio",
    /// `Value for electron-proton mass ratio`: 
    Value_ElectronProtonMassRatio, "Value_ElectronProtonMassRatio",
    /// `Value for electron-tau mass ratio`: 
    Value_ElectronTauMassRatio, "Value_ElectronTauMassRatio",
    /// `Value for electron to alpha particle mass ratio`: 
    Value_ElectronToAlphaParticleMassRatio, "Value_ElectronToAlphaParticleMassRatio",
    /// `Value for electron to shielded helion magnetic moment ratio`: 
    Value_ElectronToShieldedHelionMagneticMomentRatio, "Value_ElectronToShieldedHelionMagneticMomentRatio",
    /// `Value for electron to shielded proton magnetic moment ratio`: 
    Value_ElectronToShieldedProtonMagneticMomentRatio, "Value_ElectronToShieldedProtonMagneticMomentRatio",
    /// `Value for electron volt-atomic mass unit relationship`: 
    Value_ElectronVoltAtomicMassUnitRelationship, "Value_ElectronVoltAtomicMassUnitRelationship",
    /// `Value for electron volt-hartree relationship`: 
    Value_ElectronVoltHartreeRelationship, "Value_ElectronVoltHartreeRelationship",
    /// `Value for electron volt-hertz relationship`: 
    Value_ElectronVoltHertzRelationship, "Value_ElectronVoltHertzRelationship",
    /// `Value for electron volt-inverse meter relationship`: 
    Value_ElectronVoltInverseMeterRelationship, "Value_ElectronVoltInverseMeterRelationship",
    /// `Value for electron volt-joule relationship`: 
    Value_ElectronVoltJouleRelationship, "Value_ElectronVoltJouleRelationship",
    /// `Value for electron volt-kelvin relationship`: 
    Value_ElectronVoltKelvinRelationship, "Value_ElectronVoltKelvinRelationship",
    /// `Value for electron volt-kilogram relationship`: 
    Value_ElectronVoltKilogramRelationship, "Value_ElectronVoltKilogramRelationship",
    /// `Value for elementary charge`: 
    Value_ElementaryCharge, "Value_ElementaryCharge",
    /// `Value for elementary charge over h`: 
    Value_ElementaryChargeOverH, "Value_ElementaryChargeOverH",
    /// `Value for Faraday constant`: 
    Value_FaradayConstant, "Value_FaradayConstant",
    /// `Faraday constant for conventional electric current`: 
    Value_FaradayConstantForConventionalElectricCurrent, "Value_FaradayConstantForConventionalElectricCurrent",
    /// `Value for Fermi coupling constant`: 
    Value_FermiCouplingConstant, "Value_FermiCouplingConstant",
    /// `Value for fine-structure constant`: 
    Value_FineStructureConstant, "Value_FineStructureConstant",
    /// `Value for first radiation constant`: 
    Value_FirstRadiationConstant, "Value_FirstRadiationConstant",
    /// `Value for first radiation constant for spectral radiance`: 
    Value_FirstRadiationConstantForSpectralRadiance, "Value_FirstRadiationConstantForSpectralRadiance",
    /// `Value for gravitational constant`: 
    Value_GravitationalConstant, "Value_GravitationalConstant",
    /// `Value for hartree-atomic mass unit relationship`: 
    Value_HartreeAtomicMassUnitRelationship, "Value_HartreeAtomicMassUnitRelationship",
    /// `Value for hartree-electron volt relationship`: 
    Value_HartreeElectronVoltRelationship, "Value_HartreeElectronVoltRelationship",
    /// `Value for Hartree energy`: 
    Value_HartreeEnergy, "Value_HartreeEnergy",
    /// `Value for Hartree energy in eV`: 
    Value_HartreeEnergyInEV, "Value_HartreeEnergyInEV",
    /// `Value for hartree-hertz relationship`: 
    Value_HartreeHertzRelationship, "Value_HartreeHertzRelationship",
    /// `Value for hartree-inverse meter relationship`: 
    Value_HartreeInverseMeterRelationship, "Value_HartreeInverseMeterRelationship",
    /// `Value for hartree-joule relationship`: 
    Value_HartreeJouleRelationship, "Value_HartreeJouleRelationship",
    /// `Value for hartree-kelvin relationship`: 
    Value_HartreeKelvinRelationship, "Value_HartreeKelvinRelationship",
    /// `Value for hartree-kilogram relationship`: 
    Value_HartreeKilogramRelationship, "Value_HartreeKilogramRelationship",
    /// `Value for helion-electron mass ratio`: 
    Value_HelionElectronMassRatio, "Value_HelionElectronMassRatio",
    /// `Value for helion mass`: 
    Value_HelionMass, "Value_HelionMass",
    /// `Value for helion mass energy equivalent`: 
    Value_HelionMassEnergyEquivalent, "Value_HelionMassEnergyEquivalent",
    /// `Value for helion mass energy equivalent in MeV`: 
    Value_HelionMassEnergyEquivalentInMeV, "Value_HelionMassEnergyEquivalentInMeV",
    /// `Helion Mass (amu)`: 
    Value_HelionMassInAtomicMassUnit, "Value_HelionMassInAtomicMassUnit",
    /// `Value for helion molar mass`: 
    Value_HelionMolarMass, "Value_HelionMolarMass",
    /// `Value for helion-proton mass ratio`: 
    Value_HelionProtonMassRatio, "Value_HelionProtonMassRatio",
    /// `Value for hertz-atomic mass unit relationship`: 
    Value_HertzAtomicMassUnitRelationship, "Value_HertzAtomicMassUnitRelationship",
    /// `Value for hertz-electron volt relationship`: 
    Value_HertzElectronVoltRelationship, "Value_HertzElectronVoltRelationship",
    /// `Value for hertz-hartree relationship`: 
    Value_HertzHartreeRelationship, "Value_HertzHartreeRelationship",
    /// `Value for hertz-inverse meter relationship`: 
    Value_HertzInverseMeterRelationship, "Value_HertzInverseMeterRelationship",
    /// `Value for hertz-joule relationship`: 
    Value_HertzJouleRelationship, "Value_HertzJouleRelationship",
    /// `Value for hertz-kelvin relationship`: 
    Value_HertzKelvinRelationship, "Value_HertzKelvinRelationship",
    /// `Value for hertz-kilogram relationship`: 
    Value_HertzKilogramRelationship, "Value_HertzKilogramRelationship",
    /// `Value for inverse fine-structure constant`: 
    Value_InverseFineStructureConstant, "Value_InverseFineStructureConstant",
    /// `Value for inverse meter-atomic mass unit relationship`: 
    Value_InverseMeterAtomicMassUnitRelationship, "Value_InverseMeterAtomicMassUnitRelationship",
    /// `Value for inverse meter-electron volt relationship`: 
    Value_InverseMeterElectronVoltRelationship, "Value_InverseMeterElectronVoltRelationship",
    /// `Value for inverse meter-hartree relationship`: 
    Value_InverseMeterHartreeRelationship, "Value_InverseMeterHartreeRelationship",
    /// `Value for inverse meter-hertz relationship`: 
    Value_InverseMeterHertzRelationship, "Value_InverseMeterHertzRelationship",
    /// `Value for inverse meter-joule relationship`: 
    Value_InverseMeterJouleRelationship, "Value_InverseMeterJouleRelationship",
    /// `Value for inverse meter-kelvin relationship`: 
    Value_InverseMeterKelvinRelationship, "Value_InverseMeterKelvinRelationship",
    /// `Value for inverse meter-kilogram relationship`: 
    Value_InverseMeterKilogramRelationship, "Value_InverseMeterKilogramRelationship",
    /// `Value for inverse of conductance quantum`: 
    Value_InverseOfConductanceQuantum, "Value_InverseOfConductanceQuantum",
    /// `Value for Josephson constant`: 
    Value_JosephsonConstant, "Value_JosephsonConstant",
    /// `Value for joule-atomic mass unit relationship`: 
    Value_JouleAtomicMassUnitRelationship, "Value_JouleAtomicMassUnitRelationship",
    /// `Value for joule-electron volt relationship`: 
    Value_JouleElectronVoltRelationship, "Value_JouleElectronVoltRelationship",
    /// `Value for joule-hartree relationship`: 
    Value_JouleHartreeRelationship, "Value_JouleHartreeRelationship",
    /// `Value for joule-hertz relationship`: 
    Value_JouleHertzRelationship, "Value_JouleHertzRelationship",
    /// `Value for joule-inverse meter relationship`: 
    Value_JouleInverseMeterRelationship, "Value_JouleInverseMeterRelationship",
    /// `Value for joule-kelvin relationship`: 
    Value_JouleKelvinRelationship, "Value_JouleKelvinRelationship",
    /// `Value for joule-kilogram relationship`: 
    Value_JouleKilogramRelationship, "Value_JouleKilogramRelationship",
    /// `Value for kelvin-atomic mass unit relationship`: 
    Value_KelvinAtomicMassUnitRelationship, "Value_KelvinAtomicMassUnitRelationship",
    /// `Value for kelvin-electron volt relationship`: 
    Value_KelvinElectronVoltRelationship, "Value_KelvinElectronVoltRelationship",
    /// `Value for kelvin-hartree relationship`: 
    Value_KelvinHartreeRelationship, "Value_KelvinHartreeRelationship",
    /// `Value for kelvin-hertz relationship`: 
    Value_KelvinHertzRelationship, "Value_KelvinHertzRelationship",
    /// `Value for kelvin-inverse meter relationship`: 
    Value_KelvinInverseMeterRelationship, "Value_KelvinInverseMeterRelationship",
    /// `Value for kelvin-joule relationship`: 
    Value_KelvinJouleRelationship, "Value_KelvinJouleRelationship",
    /// `Value for kelvin-kilogram relationship`: 
    Value_KelvinKilogramRelationship, "Value_KelvinKilogramRelationship",
    /// `Value for kilogram-atomic mass unit relationship`: 
    Value_KilogramAtomicMassUnitRelationship, "Value_KilogramAtomicMassUnitRelationship",
    /// `Value for kilogram-electron volt relationship`: 
    Value_KilogramElectronVoltRelationship, "Value_KilogramElectronVoltRelationship",
    /// `Value for kilogram-hartree relationship`: 
    Value_KilogramHartreeRelationship, "Value_KilogramHartreeRelationship",
    /// `Value for kilogram-hertz relationship`: 
    Value_KilogramHertzRelationship, "Value_KilogramHertzRelationship",
    /// `Value for kilogram-inverse meter relationship`: 
    Value_KilogramInverseMeterRelationship, "Value_KilogramInverseMeterRelationship",
    /// `Value for kilogram-joule relationship`: 
    Value_KilogramJouleRelationship, "Value_KilogramJouleRelationship",
    /// `Value for kilogram-kelvin relationship`: 
    Value_KilogramKelvinRelationship, "Value_KilogramKelvinRelationship",
    /// `Value for lattice parameter of silicon`: 
    Value_LatticeParameterOfSilicon, "Value_LatticeParameterOfSilicon",
    /// `Value for lattice spacing of silicon`: 
    Value_LatticeSpacingOfSilicon, "Value_LatticeSpacingOfSilicon",
    /// `Value for Loschmidt constant 273.15 K 101.325 kPa`: 
    Value_LoschmidtConstant, "Value_LoschmidtConstant",
    /// `Value for magnetic constant`: 
    Value_MagneticConstant, "Value_MagneticConstant",
    /// `Value for magnetic flux quantum`: 
    Value_MagneticFluxQuantum, "Value_MagneticFluxQuantum",
    /// `Value for Mo x unit`: 
    Value_MoXUnit, "Value_MoXUnit",
    /// `Value for molar gas constant`: 
    Value_MolarGasConstant, "Value_MolarGasConstant",
    /// `Value for molar mass constant`: 
    Value_MolarMassConstant, "Value_MolarMassConstant",
    /// `Value for molar mass of carbon-12`: 
    Value_MolarMassOfCarbon12, "Value_MolarMassOfCarbon12",
    /// `Value for molar Planck constant`: 
    Value_MolarPlanckConstant, "Value_MolarPlanckConstant",
    /// `Value for molar Planck constant times c`: 
    Value_MolarPlanckConstantTimesC, "Value_MolarPlanckConstantTimesC",
    /// `Value for molar volume of ideal gas 273.15 K 101.325 kPa`: 
    Value_MolarVolumeOfIdealGas, "Value_MolarVolumeOfIdealGas",
    /// `Value for molar volume of silicon`: 
    Value_MolarVolumeOfSilicon, "Value_MolarVolumeOfSilicon",
    /// `Value for muon Compton wavelength`: 
    Value_MuonComptonWavelength, "Value_MuonComptonWavelength",
    /// `Value for muon Compton wavelength over 2 pi`: 
    Value_MuonComptonWavelengthOver2Pi, "Value_MuonComptonWavelengthOver2Pi",
    /// `Value for muon-electron mass ratio`: 
    Value_MuonElectronMassRatio, "Value_MuonElectronMassRatio",
    /// `Value for muon g factor`: 
    Value_MuonGFactor, "Value_MuonGFactor",
    /// `Value for muon magnetic moment`: 
    Value_MuonMagneticMoment, "Value_MuonMagneticMoment",
    /// `Value for muon magnetic moment anomaly`: 
    Value_MuonMagneticMomentAnomaly, "Value_MuonMagneticMomentAnomaly",
    /// `Value for muon magnetic moment to Bohr magneton ratio`: 
    Value_MuonMagneticMomentToBohrMagnetonRatio, "Value_MuonMagneticMomentToBohrMagnetonRatio",
    /// `Value for muon magnetic moment to nuclear magneton ratio`: 
    Value_MuonMagneticMomentToNuclearMagnetonRatio, "Value_MuonMagneticMomentToNuclearMagnetonRatio",
    /// `Value for muon mass`: 
    Value_MuonMass, "Value_MuonMass",
    /// `Value for muon mass energy equivalent`: 
    Value_MuonMassEnergyEquivalent, "Value_MuonMassEnergyEquivalent",
    /// `Value for muon mass energy equivalent in MeV`: 
    Value_MuonMassEnergyEquivalentInMeV, "Value_MuonMassEnergyEquivalentInMeV",
    /// `Muon Mass (amu)`: 
    Value_MuonMassInAtomicMassUnit, "Value_MuonMassInAtomicMassUnit",
    /// `Value for muon molar mass`: 
    Value_MuonMolarMass, "Value_MuonMolarMass",
    /// `Value for muon-neutron mass ratio`: 
    Value_MuonNeutronMassRatio, "Value_MuonNeutronMassRatio",
    /// `Value for muon-proton magnetic moment ratio`: 
    Value_MuonProtonMagneticMomentRatio, "Value_MuonProtonMagneticMomentRatio",
    /// `Value for muon-proton mass ratio`: 
    Value_MuonProtonMassRatio, "Value_MuonProtonMassRatio",
    /// `Value for muon-tau mass ratio`: 
    Value_MuonTauMassRatio, "Value_MuonTauMassRatio",
    /// `Value for natural unit of action`: 
    Value_NaturalUnitOfAction, "Value_NaturalUnitOfAction",
    /// `Value for natural unit of action in eV s`: 
    Value_NaturalUnitOfActionInEVS, "Value_NaturalUnitOfActionInEVS",
    /// `Value for natural unit of energy`: 
    Value_NaturalUnitOfEnergy, "Value_NaturalUnitOfEnergy",
    /// `Value for natural unit of energy in MeV`: 
    Value_NaturalUnitOfEnergyInMeV, "Value_NaturalUnitOfEnergyInMeV",
    /// `Value for natural unit of length`: 
    Value_NaturalUnitOfLength, "Value_NaturalUnitOfLength",
    /// `Value for natural unit of mass`: 
    Value_NaturalUnitOfMass, "Value_NaturalUnitOfMass",
    /// `Value for natural unit of momentum`: 
    Value_NaturalUnitOfMomentum, "Value_NaturalUnitOfMomentum",
    /// `Value for natural unit of momentum in MeV c^-1`: 
    Value_NaturalUnitOfMomentumInMeVPerC, "Value_NaturalUnitOfMomentumInMeVPerC",
    /// `Value for natural unit of time`: 
    Value_NaturalUnitOfTime, "Value_NaturalUnitOfTime",
    /// `Value for natural unit of velocity`: 
    Value_NaturalUnitOfVelocity, "Value_NaturalUnitOfVelocity",
    /// `Value for neutron Compton wavelength`: 
    Value_NeutronComptonWavelength, "Value_NeutronComptonWavelength",
    /// `Value for neutron Compton wavelength over 2 pi`: 
    Value_NeutronComptonWavelengthOver2Pi, "Value_NeutronComptonWavelengthOver2Pi",
    /// `Value for neutron-electron magnetic moment ratio`: 
    Value_NeutronElectronMagneticMomentRatio, "Value_NeutronElectronMagneticMomentRatio",
    /// `Value for neutron-electron mass ratio`: 
    Value_NeutronElectronMassRatio, "Value_NeutronElectronMassRatio",
    /// `Value for neutron g factor`: 
    Value_NeutronGFactor, "Value_NeutronGFactor",
    /// `Value for neutron gyromagnetic ratio`: 
    Value_NeutronGyromagneticRatio, "Value_NeutronGyromagneticRatio",
    /// `Value for neutron gyromagnetic ratio over 2 pi`: 
    Value_NeutronGyromagneticRatioOver2Pi, "Value_NeutronGyromagneticRatioOver2Pi",
    /// `Value for neutron magnetic moment`: 
    Value_NeutronMagneticMoment, "Value_NeutronMagneticMoment",
    /// `Value for neutron magnetic moment to Bohr magneton ratio`: 
    Value_NeutronMagneticMomentToBohrMagnetonRatio, "Value_NeutronMagneticMomentToBohrMagnetonRatio",
    /// `Value for neutron magnetic moment to nuclear magneton ratio`: 
    Value_NeutronMagneticMomentToNuclearMagnetonRatio, "Value_NeutronMagneticMomentToNuclearMagnetonRatio",
    /// `Value for neutron mass`: 
    Value_NeutronMass, "Value_NeutronMass",
    /// `Value for neutron mass energy equivalent`: 
    Value_NeutronMassEnergyEquivalent, "Value_NeutronMassEnergyEquivalent",
    /// `Value for neutron mass energy equivalent in MeV`: 
    Value_NeutronMassEnergyEquivalentInMeV, "Value_NeutronMassEnergyEquivalentInMeV",
    /// `Neutron Mass (amu)`: 
    Value_NeutronMassInAtomicMassUnit, "Value_NeutronMassInAtomicMassUnit",
    /// `Value for neutron molar mass`: 
    Value_NeutronMolarMass, "Value_NeutronMolarMass",
    /// `Value for neutron-muon mass ratio`: 
    Value_NeutronMuonMassRatio, "Value_NeutronMuonMassRatio",
    /// `Value for neutron-proton magnetic moment ratio`: 
    Value_NeutronProtonMagneticMomentRatio, "Value_NeutronProtonMagneticMomentRatio",
    /// `Value for neutron-proton mass ratio`: 
    Value_NeutronProtonMassRatio, "Value_NeutronProtonMassRatio",
    /// `Value for neutron-tau mass ratio`: 
    Value_NeutronTauMassRatio, "Value_NeutronTauMassRatio",
    /// `Value for neutron to shielded proton magnetic moment ratio`: 
    Value_NeutronToShieldedProtonMagneticMomentRatio, "Value_NeutronToShieldedProtonMagneticMomentRatio",
    /// `Value for Newtonian constant of gravitation`: 
    Value_NewtonianConstantOfGravitation, "Value_NewtonianConstantOfGravitation",
    /// `Newtonian constant of gravitation over hbar c`: 
    Value_NewtonianConstantOfGravitationOverHbarC, "Value_NewtonianConstantOfGravitationOverHbarC",
    /// `Value for nuclear magneton`: 
    Value_NuclearMagneton, "Value_NuclearMagneton",
    /// `Value for nuclear magneton in eV per T`: 
    Value_NuclearMagnetonInEVPerT, "Value_NuclearMagnetonInEVPerT",
    /// `Value for nuclear magneton in inverse meters per tesla`: 
    Value_NuclearMagnetonInInverseMetersPerTesla, "Value_NuclearMagnetonInInverseMetersPerTesla",
    /// `Value for nuclear magneton in K per T`: 
    Value_NuclearMagnetonInKPerT, "Value_NuclearMagnetonInKPerT",
    /// `Value for nuclear magneton in MHz per T`: 
    Value_NuclearMagnetonInMHzPerT, "Value_NuclearMagnetonInMHzPerT",
    /// `Value for permittivity of vacuum`: 
    Value_PermittivityOfVacuum, "Value_PermittivityOfVacuum",
    /// `Value for Planck constant`: 
    Value_PlanckConstant, "Value_PlanckConstant",
    /// `Value for Planck constant in eV s`: 
    Value_PlanckConstantInEVS, "Value_PlanckConstantInEVS",
    /// `Value for Planck constant over 2 pi`: 
    Value_PlanckConstantOver2Pi, "Value_PlanckConstantOver2Pi",
    /// `Value for Planck constant over 2 pi in eV s`: 
    Value_PlanckConstantOver2PiInEVS, "Value_PlanckConstantOver2PiInEVS",
    /// `Value for Planck constant over 2 pi times c in MeV fm`: 
    Value_PlanckConstantOver2PiTimesCInMeVFm, "Value_PlanckConstantOver2PiTimesCInMeVFm",
    /// `Value for Planck length`: 
    Value_PlanckLength, "Value_PlanckLength",
    /// `Value for Planck mass`: 
    Value_PlanckMass, "Value_PlanckMass",
    /// `Value for Planck mass energy equivalent in GeV`: 
    Value_PlanckMassEnergyEquivalentInGeV, "Value_PlanckMassEnergyEquivalentInGeV",
    /// `Value for Planck temperature`: 
    Value_PlanckTemperature, "Value_PlanckTemperature",
    /// `Value for Planck time`: 
    Value_PlanckTime, "Value_PlanckTime",
    /// `Value for proton charge to mass quotient`: 
    Value_ProtonChargeToMassQuotient, "Value_ProtonChargeToMassQuotient",
    /// `Value for proton Compton wavelength`: 
    Value_ProtonComptonWavelength, "Value_ProtonComptonWavelength",
    /// `Value for proton Compton wavelength over 2 pi`: 
    Value_ProtonComptonWavelengthOver2Pi, "Value_ProtonComptonWavelengthOver2Pi",
    /// `Value for proton-electron mass ratio`: 
    Value_ProtonElectronMassRatio, "Value_ProtonElectronMassRatio",
    /// `Value for proton g factor`: 
    Value_ProtonGFactor, "Value_ProtonGFactor",
    /// `Value for proton gyromagnetic ratio`: 
    Value_ProtonGyromagneticRatio, "Value_ProtonGyromagneticRatio",
    /// `Value for proton gyromagnetic ratio over 2 pi`: 
    Value_ProtonGyromagneticRatioOver2Pi, "Value_ProtonGyromagneticRatioOver2Pi",
    /// `Value for proton magnetic moment`: 
    Value_ProtonMagneticMoment, "Value_ProtonMagneticMoment",
    /// `Value for proton magnetic moment to Bohr magneton ratio`: 
    Value_ProtonMagneticMomentToBohrMagnetonRatio, "Value_ProtonMagneticMomentToBohrMagnetonRatio",
    /// `Value for proton magnetic moment to nuclear magneton ratio`: 
    Value_ProtonMagneticMomentToNuclearMagnetonRatio, "Value_ProtonMagneticMomentToNuclearMagnetonRatio",
    /// `Value for proton magnetic shielding correction`: 
    Value_ProtonMagneticShieldingCorrection, "Value_ProtonMagneticShieldingCorrection",
    /// `Value for proton mass`: 
    Value_ProtonMass, "Value_ProtonMass",
    /// `Value for proton mass energy equivalent`: 
    Value_ProtonMassEnergyEquivalent, "Value_ProtonMassEnergyEquivalent",
    /// `Value for proton mass energy equivalent in MeV`: 
    Value_ProtonMassEnergyEquivalentInMeV, "Value_ProtonMassEnergyEquivalentInMeV",
    /// `Proton Mass (amu)`: 
    Value_ProtonMassInAtomicMassUnit, "Value_ProtonMassInAtomicMassUnit",
    /// `Value for proton molar mass`: 
    Value_ProtonMolarMass, "Value_ProtonMolarMass",
    /// `Value for proton-muon mass ratio`: 
    Value_ProtonMuonMassRatio, "Value_ProtonMuonMassRatio",
    /// `Value for proton-neutron magnetic moment ratio`: 
    Value_ProtonNeutronMagneticMomentRatio, "Value_ProtonNeutronMagneticMomentRatio",
    /// `Value for proton-neutron mass ratio`: 
    Value_ProtonNeutronMassRatio, "Value_ProtonNeutronMassRatio",
    /// `Value for proton rms charge radius`: 
    Value_ProtonRmsChargeRadius, "Value_ProtonRmsChargeRadius",
    /// `Value for proton-tau mass ratio`: 
    Value_ProtonTauMassRatio, "Value_ProtonTauMassRatio",
    /// `Value for quantum of circulation`: 
    Value_QuantumOfCirculation, "Value_QuantumOfCirculation",
    /// `Value for quantum of circulation times 2`: 
    Value_QuantumOfCirculationTimes2, "Value_QuantumOfCirculationTimes2",
    /// `Value for Rydberg constant`: 
    Value_RydbergConstant, "Value_RydbergConstant",
    /// `Value for Rydberg constant times c in Hz`: 
    Value_RydbergConstantTimesCInHz, "Value_RydbergConstantTimesCInHz",
    /// `Value for Rydberg constant times hc in eV`: 
    Value_RydbergConstantTimesHcInEV, "Value_RydbergConstantTimesHcInEV",
    /// `Value for Rydberg constant times hc in J`: 
    Value_RydbergConstantTimesHcInJ, "Value_RydbergConstantTimesHcInJ",
    /// `Value for Sackur-Tetrode constant 1 K 100 kPa`: 
    Value_SackurTetrodeConstant1K100KPa, "Value_SackurTetrodeConstant1K100KPa",
    /// `Value for Sackur-Tetrode constant 1 K 101.325 kPa`: 
    Value_SackurTetrodeConstant1K101_325K, "Value_SackurTetrodeConstant1K101.325K",
    /// `Value for second radiation constant`: 
    Value_SecondRadiationConstant, "Value_SecondRadiationConstant",
    /// `Value for shielded helion gyromagnetic ratio`: 
    Value_ShieldedHelionGyromagneticRatio, "Value_ShieldedHelionGyromagneticRatio",
    /// `Value for shielded helion gyromagnetic ratio over 2 pi`: 
    Value_ShieldedHelionGyromagneticRatioOver2Pi, "Value_ShieldedHelionGyromagneticRatioOver2Pi",
    /// `Value for shielded helion magnetic moment`: 
    Value_ShieldedHelionMagneticMoment, "Value_ShieldedHelionMagneticMoment",
    /// `Value for shielded helion magnetic moment to Bohr magneton ratio`: 
    Value_ShieldedHelionMagneticMomentToBohrMagnetonRatio, "Value_ShieldedHelionMagneticMomentToBohrMagnetonRatio",
    /// `Value for shielded helion magnetic moment to nuclear magneton ratio`: 
    Value_ShieldedHelionMagneticMomentToNuclearMagnetonRatio, "Value_ShieldedHelionMagneticMomentToNuclearMagnetonRatio",
    /// `Value for shielded helion to proton magnetic moment ratio`: 
    Value_ShieldedHelionToProtonMagneticMomentRatio, "Value_ShieldedHelionToProtonMagneticMomentRatio",
    /// `Value for shielded helion to shielded proton magnetic moment ratio`: 
    Value_ShieldedHelionToShieldedProtonMagneticMomentRatio, "Value_ShieldedHelionToShieldedProtonMagneticMomentRatio",
    /// `Value for shielded proton gyromagnetic ratio`: 
    Value_ShieldedProtonGyromagneticRatio, "Value_ShieldedProtonGyromagneticRatio",
    /// `Value for shielded proton gyromagnetic ratio over 2 pi`: 
    Value_ShieldedProtonGyromagneticRatioOver2Pi, "Value_ShieldedProtonGyromagneticRatioOver2Pi",
    /// `Value for shielded proton magnetic moment`: 
    Value_ShieldedProtonMagneticMoment, "Value_ShieldedProtonMagneticMoment",
    /// `Value for shielded proton magnetic moment to Bohr magneton ratio`: 
    Value_ShieldedProtonMagneticMomentToBohrMagnetonRatio, "Value_ShieldedProtonMagneticMomentToBohrMagnetonRatio",
    /// `Value for shielded proton magnetic moment to nuclear magneton ratio`: 
    Value_ShieldedProtonMagneticMomentToNuclearMagnetonRatio, "Value_ShieldedProtonMagneticMomentToNuclearMagnetonRatio",
    /// `Value for velocity of light`: 
    Value_SpeedOfLight, "Value_SpeedOfLight",
    /// `Value for speed of light in a vacuum`: 
    Value_SpeedOfLight_Vacuum, "Value_SpeedOfLight_Vacuum",
    /// `Value for speed of light in vacuum (Imperial units)`: 
    Value_SpeedOfLight_Vacuum_Imperial, "Value_SpeedOfLight_Vacuum_Imperial",
    /// `Value for standard acceleration of gravity`: 
    Value_StandardAccelerationOfGravity, "Value_StandardAccelerationOfGravity",
    /// `Value for standard atmosphere`: 
    Value_StandardAtmosphere, "Value_StandardAtmosphere",
    /// `Value for Stefan-Boltzmann Constant`: 
    Value_StefanBoltzmannConstant, "Value_StefanBoltzmannConstant",
    /// `Value for tau Compton wavelength`: 
    Value_TauComptonWavelength, "Value_TauComptonWavelength",
    /// `Value for tau Compton wavelength over 2 pi`: 
    Value_TauComptonWavelengthOver2Pi, "Value_TauComptonWavelengthOver2Pi",
    /// `Value for tau-electron mass ratio`: 
    Value_TauElectronMassRatio, "Value_TauElectronMassRatio",
    /// `Value for tau mass`: 
    Value_TauMass, "Value_TauMass",
    /// `Value for tau mass energy equivalent`: 
    Value_TauMassEnergyEquivalent, "Value_TauMassEnergyEquivalent",
    /// `Value for tau mass energy equivalent in MeV`: 
    Value_TauMassEnergyEquivalentInMeV, "Value_TauMassEnergyEquivalentInMeV",
    /// `Tau Mass (amu)`: 
    Value_TauMassInAtomicMassUnit, "Value_TauMassInAtomicMassUnit",
    /// `Value for tau molar mass`: 
    Value_TauMolarMass, "Value_TauMolarMass",
    /// `Value for tau-muon mass ratio`: 
    Value_TauMuonMassRatio, "Value_TauMuonMassRatio",
    /// `Value for tau-neutron mass ratio`: 
    Value_TauNeutronMassRatio, "Value_TauNeutronMassRatio",
    /// `Value for tau-proton mass ratio`: 
    Value_TauProtonMassRatio, "Value_TauProtonMassRatio",
    /// `Value for Thomson cross section`: 
    Value_ThomsonCrossSection, "Value_ThomsonCrossSection",
    /// `Value for triton-electron magnetic moment ratio`: 
    Value_TritonElectronMagneticMomentRatio, "Value_TritonElectronMagneticMomentRatio",
    /// `Value for triton-electron mass ratio`: 
    Value_TritonElectronMassRatio, "Value_TritonElectronMassRatio",
    /// `Value for triton g factor`: 
    Value_TritonGFactor, "Value_TritonGFactor",
    /// `Value for triton magnetic moment`: 
    Value_TritonMagneticMoment, "Value_TritonMagneticMoment",
    /// `Value for triton magnetic moment to Bohr magneton ratio`: 
    Value_TritonMagneticMomentToBohrMagnetonRatio, "Value_TritonMagneticMomentToBohrMagnetonRatio",
    /// `Value for triton magnetic moment to nuclear magneton ratio`: 
    Value_TritonMagneticMomentToNuclearMagnetonRatio, "Value_TritonMagneticMomentToNuclearMagnetonRatio",
    /// `Value for triton mass`: 
    Value_TritonMass, "Value_TritonMass",
    /// `Value for triton mass energy equivalent`: 
    Value_TritonMassEnergyEquivalent, "Value_TritonMassEnergyEquivalent",
    /// `Value for triton mass energy equivalent in MeV`: 
    Value_TritonMassEnergyEquivalentInMeV, "Value_TritonMassEnergyEquivalentInMeV",
    /// `Triton Mass (amu)`: 
    Value_TritonMassInAtomicMassUnit, "Value_TritonMassInAtomicMassUnit",
    /// `Value for triton molar mass`: 
    Value_TritonMolarMass, "Value_TritonMolarMass",
    /// `Value for triton-neutron magnetic moment ratio`: 
    Value_TritonNeutronMagneticMomentRatio, "Value_TritonNeutronMagneticMomentRatio",
    /// `Value for triton-proton magnetic moment ratio`: 
    Value_TritonProtonMagneticMomentRatio, "Value_TritonProtonMagneticMomentRatio",
    /// `Value for triton-proton mass ratio`: 
    Value_TritonProtonMassRatio, "Value_TritonProtonMassRatio",
    /// `Value for unified atomic mass unit`: 
    Value_UnifiedAtomicMassUnit, "Value_UnifiedAtomicMassUnit",
    /// `Value for von Klitzing constant`: 
    Value_VonKlitzingConstant, "Value_VonKlitzingConstant",
    /// `Value for weak mixing angle`: 
    Value_WeakMixingAngle, "Value_WeakMixingAngle",
    /// `Value for Wien frequency displacement law constant`: 
    Value_WienFrequencyDisplacementLawConstant, "Value_WienFrequencyDisplacementLawConstant",
    /// `Value for Wien wavelength displacement law constant`: 
    Value_WienWavelengthDisplacementLawConstant, "Value_WienWavelengthDisplacementLawConstant",
    /// `Von Klitzing constant`: 
    VonKlitzingConstant, "VonKlitzingConstant",
    /// `Weak mixing angle`: 
    WeakMixingAngle, "WeakMixingAngle",
    /// `Wien frequency displacement law constant`: 
    WienFrequencyDisplacementLawConstant, "WienFrequencyDisplacementLawConstant",
    /// `Wien wavelength displacement law constant`: 
    WienWavelengthDisplacementLawConstant, "WienWavelengthDisplacementLawConstant"
);
